@@ -46,9 +46,9 @@ import pango
 import openstreetmap
 from os import path
 import re
-from cachedownloader import HTMLAware
+from cachedownloader import HTMLManipulations
 
-class SimpleGui(object, HTMLAware):
+class SimpleGui():
     USES = ['gpsprovider']
     XMLFILE = "freerunner.glade"
 
@@ -108,7 +108,7 @@ class SimpleGui(object, HTMLAware):
     ARROW_LINE_WIDTH = 3
     NORTH_INDICATOR_SIZE = 30
     FONT_NORTH_INDICATOR = pango.FontDescription("Sans 9")
-    FONT_SUN_INDICATOR = pango.FontDescription("Sans 11")
+    FONT_SUN_INDICATOR = pango.FontDescription("Sans 8")
 
 
     # quality indicator
@@ -132,7 +132,6 @@ class SimpleGui(object, HTMLAware):
         'options_password',
         'download_map_path'
     ]
-
                 
     def __init__(self, core, pointprovider, userpointprovider, dataroot):
     
@@ -744,7 +743,6 @@ class SimpleGui(object, HTMLAware):
             p = self._coord2point(c)
 
             if c.alter_lat != None and (c.alter_lat != 0 and c.alter_lon != 0):
-                print c.alter_lat
                 x = self._coord2point(geo.Coordinate(c.alter_lat, c.alter_lon))
                 if x != p:
                     self.pixmap_marks.draw_line(xgc, p[0], p[1], x[0], x[1])
@@ -1680,7 +1678,7 @@ class SimpleGui(object, HTMLAware):
         text = re.sub(r"""(?i)<img[^>]+alt=["']?([^'"> ]+)[^>]+>""", SimpleGui.replace_image_tag, text)
         text = re.sub(r'(?i)<(br|p)[^>]*?>', "\n", text)
         text = re.sub(r'<[^>]*?>', '', text)
-        text = SimpleGui._decode_htmlentities(text)
+        text = HTMLManipulations._decode_htmlentities(text)
         text = re.sub(r'[\n\r]+\s*[\n\r]+', '\n', text)
         return text.strip()
                 
@@ -1711,7 +1709,7 @@ class SimpleGui(object, HTMLAware):
             target_distance = self.gps_data.position.distance_to(self.current_target)
             if target_distance >= 1000:
                 label = "%3dkm" % round(target_distance / 1000)
-            elif display_dist >= 100:
+            elif target_distance >= 100:
                 label = "%3dm" % round(target_distance)
             else:
                 label = "%2.1fm" % round(target_distance, 1)
